@@ -19,7 +19,6 @@ import (
 	"github.com/tidwall/gjson"
 
 	"github.com/infracost/infracost/internal/config"
-	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/testutil"
 )
 
@@ -86,37 +85,51 @@ func TestBreakdownFormatJsonWithTags(t *testing.T) {
 	)
 }
 
+func TestBreakdownFormatJsonWithTagsAftModule(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+
+	GoldenFileCommandTest(
+		t,
+		testName,
+		[]string{
+			"breakdown",
+			"--format", "json",
+			"--path", dir,
+		},
+		&GoldenFileOptions{
+			CaptureLogs: true,
+			IsJSON:      true,
+			JSONInclude: regexp.MustCompile("^(defaultTags|tags|name)$"),
+			JSONExclude: regexp.MustCompile("^(costComponents|pastBreakdown)$"),
+			RegexFilter: regexp.MustCompile("(tags-mock|bucket-mock)"),
+		}, func(ctx *config.RunContext) {
+			ctx.Config.TagPoliciesEnabled = true
+		},
+	)
+}
+
 func TestBreakdownFormatJsonWithTagsAliasedProvider(t *testing.T) {
 	testName := testutil.CalcGoldenFileTestdataDirName()
 	dir := path.Join("./testdata", testName)
 
-	runWithEnv := func(env map[string]string) func(t *testing.T) {
-		return func(t *testing.T) {
-			GoldenFileCommandTest(
-				t,
-				testName,
-				[]string{
-					"breakdown",
-					"--format", "json",
-					"--path", dir,
-				},
-				&GoldenFileOptions{
-					CaptureLogs: true,
-					IsJSON:      true,
-					JSONInclude: regexp.MustCompile("^(defaultTags|tags|name)$"),
-					JSONExclude: regexp.MustCompile("^(costComponents|pastBreakdown)$"),
-					Env:         env,
-				}, func(ctx *config.RunContext) {
-					ctx.Config.TagPoliciesEnabled = true
-				},
-			)
-		}
-	}
-
-	t.Run("with old hcl evaluator", runWithEnv(nil))
-	t.Run("with graph evaluator", runWithEnv(map[string]string{
-		"INFRACOST_GRAPH_EVALUATOR": "true",
-	}))
+	GoldenFileCommandTest(
+		t,
+		testName,
+		[]string{
+			"breakdown",
+			"--format", "json",
+			"--path", path.Join(dir, "project"),
+		},
+		&GoldenFileOptions{
+			CaptureLogs: true,
+			IsJSON:      true,
+			JSONInclude: regexp.MustCompile("^(defaultTags|tags|name)$"),
+			JSONExclude: regexp.MustCompile("^(costComponents|pastBreakdown)$"),
+		}, func(ctx *config.RunContext) {
+			ctx.Config.TagPoliciesEnabled = true
+		},
+	)
 }
 
 func TestBreakdownFormatJsonWithTagsAzure(t *testing.T) {
@@ -555,6 +568,16 @@ func TestBreakdownTerragruntHCLDepsOutput(t *testing.T) {
 	)
 }
 
+func TestBreakdownTerragruntIncludeDeps(t *testing.T) {
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{"breakdown", "--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())},
+		&GoldenFileOptions{CaptureLogs: true},
+	)
+}
+
 func TestBreakdownTerragruntHCLModuleOutputForEach(t *testing.T) {
 	GoldenFileCommandTest(
 		t,
@@ -592,14 +615,9 @@ func TestBreakdownTerragruntGetEnv(t *testing.T) {
 }
 
 func TestBreakdownTerragruntGetEnvWithWhitelist(t *testing.T) {
-	os.Setenv("UNSAFE_VAR", "test")
-	os.Setenv("SAFE_VAR", "test-prod")
-	os.Setenv("INFRACOST_SAFE_ENVS", "TEST,SAFE_VAR,FOO")
-	defer func() {
-		os.Unsetenv("UNSAFE_VAR")
-		os.Unsetenv("SAFE_VAR")
-		os.Unsetenv("INFRACOST_SAFE_ENVS")
-	}()
+	t.Setenv("UNSAFE_VAR", "test")
+	t.Setenv("SAFE_VAR", "test-prod")
+	t.Setenv("INFRACOST_SAFE_ENVS", "TEST,SAFE_VAR,FOO")
 
 	GoldenFileCommandTest(t, testutil.CalcGoldenFileTestdataDirName(), []string{"breakdown", "--path", path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName())}, nil)
 }
@@ -740,9 +758,10 @@ func TestBreakdownWithPrivateSshModulePopulatesErrors(t *testing.T) {
 	msg := errs[0].Get("message").String()
 	data := errs[0].Get("data").Map()
 
-	assert.Equal(t, schema.DiagPrivateModuleDownloadFailure, int(code))
-	assert.Contains(t, msg, "Failed to download remote module \"ec2_cluster\"")
+	assert.Equal(t, 201, int(code))
+	assert.Contains(t, msg, "Failed to download module \"git@github.com:someorg/terraform_modules.git\"")
 	assert.Equal(t, data["source"].String(), "ssh")
+	assert.Equal(t, data["moduleSource"].String(), "git@github.com:someorg/terraform_modules.git")
 }
 
 func TestBreakdownWithPrivateHttpsModulePopulatesErrors(t *testing.T) {
@@ -766,9 +785,10 @@ func TestBreakdownWithPrivateHttpsModulePopulatesErrors(t *testing.T) {
 	msg := errs[0].Get("message").String()
 	data := errs[0].Get("data").Map()
 
-	assert.Equal(t, schema.DiagPrivateModuleDownloadFailure, int(code))
-	assert.Contains(t, msg, "Failed to download remote module \"ec2_cluster\"")
+	assert.Equal(t, 201, int(code))
+	assert.Contains(t, msg, "Failed to download module \"github.com/someorg/terraform_modules.git\"")
 	assert.Equal(t, data["source"].String(), "https")
+	assert.Equal(t, data["moduleSource"].String(), "github.com/someorg/terraform_modules.git")
 }
 
 func TestBreakdownWithPrivateTerraformRegistryModulePopulatesErrors(t *testing.T) {
@@ -948,6 +968,19 @@ func TestBreakdownWithDeepMergeModule(t *testing.T) {
 	)
 }
 
+func TestBreakdownWithNestedProviderAliases(t *testing.T) {
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName()),
+		},
+		nil,
+	)
+}
+
 func TestBreakdownWithMultipleProviders(t *testing.T) {
 	GoldenFileCommandTest(
 		t,
@@ -961,6 +994,20 @@ func TestBreakdownWithMultipleProviders(t *testing.T) {
 	)
 }
 
+func TestBreakdownWithProvidersDependingOnData(t *testing.T) {
+	// This test doesn't pass for the non-graph evaluator
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path",
+			path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName()),
+		},
+		&GoldenFileOptions{IgnoreNonGraph: true},
+	)
+}
+
 func TestBreakdownMultiProjectWithError(t *testing.T) {
 	testName := testutil.CalcGoldenFileTestdataDirName()
 	dir := path.Join("./testdata", testName)
@@ -1060,6 +1107,7 @@ func TestBreakdownWithDataBlocksInSubmod(t *testing.T) {
 }
 
 func TestBreakdownWithPolicyDataUploadHCL(t *testing.T) {
+	sep := []byte("===\n")
 	ts, uploadWriter := GraphqlTestServerWithWriter(map[string]string{
 		"policyResourceAllowList": policyResourceAllowlistGraphQLResponse,
 		"storePolicyResources":    storePolicyResourcesGraphQLResponse,
@@ -1082,10 +1130,14 @@ func TestBreakdownWithPolicyDataUploadHCL(t *testing.T) {
 		}, func(ctx *config.RunContext) {
 			ctx.Config.PolicyV2APIEndpoint = ts.URL
 			ctx.Config.PoliciesEnabled = true
+			uploadWriter.Write(sep)
 		},
 	)
 
-	testutil.AssertGoldenFile(t, path.Join("./testdata", testName, testName+"-upload.golden"), uploadWriter.Bytes())
+	pp := strings.Split(uploadWriter.String(), string(sep))
+	for _, p := range pp[1:] {
+		testutil.AssertGoldenFile(t, path.Join("./testdata", testName, testName+"-upload.golden"), []byte(p))
+	}
 }
 
 func TestBreakdownWithMockedMerge(t *testing.T) {
@@ -1115,6 +1167,7 @@ func TestBreakdownWithDynamicIterator(t *testing.T) {
 }
 
 func TestBreakdownWithPolicyDataUploadPlanJson(t *testing.T) {
+	sep := []byte("===\n")
 	ts, uploadWriter := GraphqlTestServerWithWriter(map[string]string{
 		"policyResourceAllowList": policyResourceAllowlistGraphQLResponse,
 		"storePolicyResources":    storePolicyResourcesGraphQLResponse,
@@ -1137,13 +1190,18 @@ func TestBreakdownWithPolicyDataUploadPlanJson(t *testing.T) {
 		}, func(ctx *config.RunContext) {
 			ctx.Config.PolicyV2APIEndpoint = ts.URL
 			ctx.Config.PoliciesEnabled = true
+			uploadWriter.Write(sep)
 		},
 	)
 
-	testutil.AssertGoldenFile(t, path.Join("./testdata", testName, testName+"-upload.golden"), uploadWriter.Bytes())
+	pp := strings.Split(uploadWriter.String(), string(sep))
+	for _, p := range pp[1:] {
+		testutil.AssertGoldenFile(t, path.Join("./testdata", testName, testName+"-upload.golden"), []byte(p))
+	}
 }
 
 func TestBreakdownWithPolicyDataUploadTerragrunt(t *testing.T) {
+	sep := []byte("===\n")
 	ts, uploadWriter := GraphqlTestServerWithWriter(map[string]string{
 		"policyResourceAllowList": policyResourceAllowlistGraphQLResponse,
 		"storePolicyResources":    storePolicyResourcesGraphQLResponse,
@@ -1166,10 +1224,14 @@ func TestBreakdownWithPolicyDataUploadTerragrunt(t *testing.T) {
 		}, func(ctx *config.RunContext) {
 			ctx.Config.PolicyV2APIEndpoint = ts.URL
 			ctx.Config.PoliciesEnabled = true
+			uploadWriter.Write(sep)
 		},
 	)
 
-	testutil.AssertGoldenFile(t, path.Join("./testdata", testName, testName+"-upload.golden"), stripDynamicValues(uploadWriter.Bytes()))
+	pp := strings.Split(uploadWriter.String(), string(sep))
+	for _, p := range pp[1:] {
+		testutil.AssertGoldenFile(t, path.Join("./testdata", testName, testName+"-upload.golden"), stripDynamicValues([]byte(p)))
+	}
 }
 
 func TestBreakdownConfigFileWithSkipAutoDetect(t *testing.T) {
@@ -1187,3 +1249,39 @@ func TestBreakdownConfigFileWithSkipAutoDetect(t *testing.T) {
 		},
 	)
 }
+
+func TestBreakdownInvalidAPIKey(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path", dir,
+		},
+		nil,
+		func(ctx *config.RunContext) {
+			ctx.Config.APIKey = "BAD_KEY"
+			ctx.Config.Credentials.APIKey = "BAD_KEY"
+		},
+	)
+}
+
+func TestBreakdownEmptyAPIKey(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path", dir,
+		},
+		nil,
+		func(ctx *config.RunContext) {
+			ctx.Config.APIKey = ""
+			ctx.Config.Credentials.APIKey = ""
+		},
+	)
+}
