@@ -27,6 +27,7 @@ var (
 	versionRegex     = regexp.MustCompile(`Infracost v.*`)
 	panicRegex       = regexp.MustCompile(`runtime\serror:([\w\d\n\r\[\]\:\/\.\\(\)\+\,\{\}\*\@\s\?]*)Environment`)
 	pathRegex        = regexp.MustCompile(`(/.*/)(infracost/infracost/cmd/infracost/testdata/.*)`)
+	credsRegex       = regexp.MustCompile(`/.*/credentials\.yml`)
 )
 
 type GoldenFileOptions = struct {
@@ -35,11 +36,11 @@ type GoldenFileOptions = struct {
 	IsJSON      bool
 	JSONInclude *regexp.Regexp
 	JSONExclude *regexp.Regexp
+	RegexFilter *regexp.Regexp
 	Env         map[string]string
 	// RunTerraformCLI sets the cmd test to also run the cmd with --terraform-force-cli set
 	RunTerraformCLI bool
-	// OnlyRunTerraformCLI sets the cmd test to only run cmd with --terraform-force-cli set and ignores the HCL parsing.
-	OnlyRunTerraformCLI bool
+	IgnoreNonGraph  bool
 }
 
 func DefaultOptions() *GoldenFileOptions {
@@ -51,13 +52,20 @@ func DefaultOptions() *GoldenFileOptions {
 }
 
 func GoldenFileCommandTest(t *testing.T, testName string, args []string, testOptions *GoldenFileOptions, ctxOptions ...func(ctx *config.RunContext)) {
-	if testOptions == nil || !testOptions.OnlyRunTerraformCLI {
+	if testOptions == nil || !testOptions.IgnoreNonGraph {
 		t.Run("HCL", func(t *testing.T) {
 			goldenFileCommandTest(t, testName, args, testOptions, true, ctxOptions...)
 		})
 	}
 
-	if testOptions != nil && (testOptions.RunTerraformCLI || testOptions.OnlyRunTerraformCLI) {
+	t.Run("HCL Graph", func(t *testing.T) {
+		ctxOptions = append(ctxOptions, func(ctx *config.RunContext) {
+			ctx.Config.GraphEvaluator = true
+		})
+		goldenFileCommandTest(t, testName, args, testOptions, true, ctxOptions...)
+	})
+
+	if testOptions != nil && (testOptions.RunTerraformCLI) {
 		t.Run("CLI", func(t *testing.T) {
 			tfCLIArgs := make([]string, len(args)+2)
 			copy(tfCLIArgs, args)
@@ -169,6 +177,11 @@ func GetCommandOutput(t *testing.T, args []string, testOptions *GoldenFileOption
 		actual = append(actual, logBuf.Bytes()...)
 	}
 
+	if testOptions.RegexFilter != nil {
+		actual = testOptions.RegexFilter.ReplaceAll(actual, []byte("REGEX_FILTER"))
+
+	}
+
 	return stripDynamicValues(actual)
 }
 
@@ -225,6 +238,7 @@ func stripDynamicValues(actual []byte) []byte {
 	actual = versionRegex.ReplaceAll(actual, []byte("Infracost vREPLACED_VERSION"))
 	actual = panicRegex.ReplaceAll(actual, []byte("runtime error: REPLACED ERROR\nEnvironment"))
 	actual = pathRegex.ReplaceAll(actual, []byte("REPLACED_PROJECT_PATH/$2"))
+	actual = credsRegex.ReplaceAll(actual, []byte("REPLACED_CREDENTIALS_PATH"))
 
 	return actual
 }
@@ -385,8 +399,8 @@ var policyResourceAllowlistGraphQLResponse = `[
   }
 ]`
 
-var storePolicyResourcesGraphQLResponse = `[{"data": 
-	{"storePolicyResources": 
+var storePolicyResourcesGraphQLResponse = `[{"data":
+	{"storePolicyResources":
 		{ "sha": "someshastring" }
 	}
 }]
