@@ -265,11 +265,11 @@ func loadCloudSettings(ctx *config.RunContext) {
 	ctx.Config.EnableCloudForOrganization = result.CloudEnabled
 	if result.UsageAPIEnabled && ctx.Config.UsageAPIEndpoint == "" {
 		ctx.Config.UsageAPIEndpoint = ctx.Config.DashboardAPIEndpoint
-		logging.Logger.Info().Msg("Enabled usage API")
+		logging.Logger.Debug().Msg("Enabled usage API")
 	}
 	if result.ActualCostsEnabled && ctx.Config.UsageAPIEndpoint != "" {
 		ctx.Config.UsageActualCosts = true
-		logging.Logger.Info().Msg("Enabled actual costs")
+		logging.Logger.Debug().Msg("Enabled actual costs")
 	}
 
 	if (result.PoliciesAPIEnabled || result.TagsAPIEnabled) && ctx.Config.PolicyV2APIEndpoint == "" {
@@ -279,12 +279,12 @@ func loadCloudSettings(ctx *config.RunContext) {
 
 	if result.PoliciesAPIEnabled {
 		ctx.Config.PoliciesEnabled = true
-		logging.Logger.Info().Msg("Enabled policies V2")
+		logging.Logger.Debug().Msg("Enabled policies V2")
 	}
 
 	if result.TagsAPIEnabled {
 		ctx.Config.TagPoliciesEnabled = true
-		logging.Logger.Info().Msg("Enabled tag policies")
+		logging.Logger.Debug().Msg("Enabled tag policies")
 	}
 }
 
