@@ -240,20 +240,17 @@ func (r *parallelRunner) run() ([]projectResult, error) {
 
 	var i int
 	for _, p := range r.runCtx.Config.Projects {
-		ctx := config.NewProjectContext(r.runCtx, p, map[string]interface{}{})
 		detected, err := providers.Detect(r.runCtx, p, r.prior == nil)
-
 		if err != nil {
 			m := fmt.Sprintf("%s\n\n", err)
-			m += fmt.Sprintf("Try adding a config-file to configure how Infracost should run. See %s for details and examples.", ui.LinkString("https://infracost.io/config-file"))
+			m += fmt.Sprintf("  Try adding a config-file to configure how Infracost should run. See %s for details and examples.", ui.LinkString("https://infracost.io/config-file"))
 
-			err = clierror.NewCLIError(errors.New(m), "Could not detect path type")
-			queue = append(queue, projectJob{index: i, err: err, ctx: ctx})
+			queue = append(queue, projectJob{index: i, err: schema.NewEmptyPathTypeError(errors.New(m)), ctx: config.NewProjectContext(r.runCtx, p, map[string]interface{}{})})
 			continue
 		}
 
 		for _, provider := range detected {
-			queue = append(queue, projectJob{index: i, provider: provider, ctx: ctx})
+			queue = append(queue, projectJob{index: i, provider: provider})
 			i++
 		}
 	}
@@ -278,18 +275,21 @@ func (r *parallelRunner) run() ([]projectResult, error) {
 
 			for job := range jobs {
 				var configProjects *projectOutput
+				ctx := job.ctx
 				if job.err != nil {
 					configProjects = newErroredProject(job.ctx, job.err)
 				} else {
 					configProjects, err = r.runProvider(job)
+					ctx = job.provider.Context()
 					if err != nil {
-						configProjects = newErroredProject(job.ctx, err)
+						configProjects = newErroredProject(ctx, err)
 					}
+
 				}
 
 				projectResultChan <- projectResult{
 					index:      job.index,
-					ctx:        job.ctx,
+					ctx:        ctx,
 					projectOut: configProjects,
 				}
 			}
@@ -338,7 +338,8 @@ func (r *parallelRunner) printParallelMsg(queue []projectJob) {
 }
 
 func (r *parallelRunner) runProvider(job projectJob) (*projectOutput, error) {
-	mux := r.pathMuxs[job.ctx.ProjectConfig.Path]
+	path := job.provider.Context().ProjectConfig.Path
+	mux := r.pathMuxs[path]
 	if mux != nil {
 		mux.Lock()
 		defer mux.Unlock()
@@ -351,9 +352,9 @@ func (r *parallelRunner) runProvider(job projectJob) (*projectOutput, error) {
 		return nil, clierror.NewCLIError(errors.New(m), "Cannot use Terraform state JSON with the infracost diff command")
 	}
 
-	m := fmt.Sprintf("Detected %s at %s", job.provider.DisplayType(), ui.DisplayPath(job.ctx.ProjectConfig.Path))
+	m := fmt.Sprintf("Detected %s at %s", job.provider.DisplayType(), ui.DisplayPath(path))
 	if job.provider.Type() == "terraform_dir" {
-		m = fmt.Sprintf("Evaluating %s at %s", job.provider.DisplayType(), ui.DisplayPath(job.ctx.ProjectConfig.Path))
+		m = fmt.Sprintf("Evaluating %s at %s", job.provider.DisplayType(), ui.DisplayPath(path))
 	}
 
 	if r.runCtx.Config.IsLogging() {
@@ -364,7 +365,7 @@ func (r *parallelRunner) runProvider(job projectJob) (*projectOutput, error) {
 
 	// Generate usage file
 	if r.runCtx.Config.SyncUsageFile {
-		err := r.generateUsageFile(job.ctx, job.provider)
+		err := r.generateUsageFile(job.provider)
 		if err != nil {
 			return nil, fmt.Errorf("Error generating usage file %w", err)
 		}
@@ -373,9 +374,9 @@ func (r *parallelRunner) runProvider(job projectJob) (*projectOutput, error) {
 	// Load usage data
 	var usageFile *usage.UsageFile
 
-	if job.ctx.ProjectConfig.UsageFile != "" {
+	if job.provider.Context().ProjectConfig.UsageFile != "" {
 		var err error
-		usageFile, err = usage.LoadUsageFile(job.ctx.ProjectConfig.UsageFile)
+		usageFile, err = usage.LoadUsageFile(job.provider.Context().ProjectConfig.UsageFile)
 		if err != nil {
 			return nil, err
 		}
@@ -390,7 +391,7 @@ func (r *parallelRunner) runProvider(job projectJob) (*projectOutput, error) {
 			)
 		}
 
-		job.ctx.ContextValues.SetValue("hasUsageFile", true)
+		job.provider.Context().ContextValues.SetValue("hasUsageFile", true)
 	} else {
 		usageFile = usage.NewBlankUsageFile()
 	}
@@ -450,7 +451,7 @@ func (r *parallelRunner) runProvider(job projectJob) (*projectOutput, error) {
 			if errors.As(err, &apiErr) {
 				switch apiErr.ErrorCode {
 				case apiclient.ErrorCodeExceededQuota:
-					return nil, &schema.ProjectDiag{Code: schema.DiagRunQuotaExceeded, Message: apiErr.Msg}
+					return nil, schema.NewDiagRunQuotaExceeded(apiErr)
 				case apiclient.ErrorCodeAPIKeyInvalid:
 					return nil, fmt.Errorf("%v\n%s %s %s %s %s\n%s %s.\n%s %s %s",
 						apiErr.Msg,
@@ -479,7 +480,7 @@ func (r *parallelRunner) runProvider(job projectJob) (*projectOutput, error) {
 
 	t2 := time.Now()
 	taken := t2.Sub(t1).Milliseconds()
-	job.ctx.ContextValues.SetValue("tfProjectRunTimeMs", taken)
+	job.provider.Context().ContextValues.SetValue("tfProjectRunTimeMs", taken)
 
 	spinner.Success()
 
@@ -608,7 +609,9 @@ func (r *parallelRunner) populateActualCosts(projects []*schema.Project) {
 	}
 }
 
-func (r *parallelRunner) generateUsageFile(ctx *config.ProjectContext, provider schema.Provider) error {
+func (r *parallelRunner) generateUsageFile(provider schema.Provider) error {
+	ctx := provider.Context()
+
 	if ctx.ProjectConfig.UsageFile == "" {
 		// This should not happen as we check earlier in the code that usage-file is not empty when sync-usage-file flag is on.
 		return fmt.Errorf("Error generating usage: no usage file given")
@@ -898,7 +901,7 @@ func buildRunEnv(runCtx *config.RunContext, projectContexts []*config.ProjectCon
 }
 
 func newErroredProject(ctx *config.ProjectContext, err error) *projectOutput {
-	metadata := config.DetectProjectMetadata(ctx.ProjectConfig.Path)
+	metadata := schema.DetectProjectMetadata(ctx.ProjectConfig.Path)
 	metadata.Type = "error"
 	metadata.AddError(err)
 
@@ -909,3 +912,61 @@ func newErroredProject(ctx *config.ProjectContext, err error) *projectOutput {
 
 	return &projectOutput{projects: []*schema.Project{schema.NewProject(name, metadata)}}
 }
+
+// runCommandFunc is a function that runs a command and returns an error this is
+// used by cobra.RunE.
+type runCommandFunc func(cmd *cobra.Command, args []string) error
+
+// runCommandMiddleware is a function that wraps a runCommandFunc and returns a
+// new runCommandFunc. This is used to add functionality to a command without
+// modifying the command itself. Middleware can be chained together to add
+// multiple pieces of functionality.
+//
+//nolint:deadcode,unused
+type runCommandMiddleware func(ctx *config.RunContext, next runCommandFunc) runCommandFunc
+
+// checkAPIKeyIsValid is a runCommandMiddleware that checks if the API key is
+// valid before running the command.
+func checkAPIKeyIsValid(ctx *config.RunContext, next runCommandFunc) runCommandFunc {
+	return func(cmd *cobra.Command, args []string) error {
+		if ctx.Config.APIKey == "" {
+			return fmt.Errorf("%s %s %s %s %s\n%s %s.\n%s %s %s",
+				ui.PrimaryString("INFRACOST_API_KEY"),
+				"is not set but is required, check your",
+				"environment variable is named correctly or add your API key to your",
+				ui.PrimaryString(config.CredentialsFilePath()),
+				"credentials file.",
+				"If you recently regenerated your API key, you can retrieve it from",
+				ui.LinkString(ctx.Config.DashboardEndpoint),
+				"See",
+				ui.LinkString("https://infracost.io/support"),
+				"if you continue having issues.")
+		}
+
+		pricingClient := apiclient.NewPricingAPIClient(ctx)
+		_, err := pricingClient.DoQueries([]apiclient.GraphQLQuery{
+			{},
+		})
+
+		var apiError *apiclient.APIError
+		if errors.As(err, &apiError) {
+			if apiError.ErrorCode == apiclient.ErrorCodeAPIKeyInvalid {
+				return fmt.Errorf("%s %s %s %s %s\n%s %s.\n%s %s %s",
+					"Invalid API Key, please check your",
+					ui.PrimaryString("INFRACOST_API_KEY"),
+					"environment variable or",
+					ui.PrimaryString(config.CredentialsFilePath()),
+					"credentials file.",
+					"If you recently regenerated your API key, you can retrieve it from",
+					ui.LinkString(ctx.Config.DashboardEndpoint),
+					"See",
+					ui.LinkString("https://infracost.io/support"),
+					"if you continue having issues.",
+				)
+
+			}
+		}
+
+		return next(cmd, args)
+	}
+}
