@@ -31,6 +31,9 @@ type AutodetectConfig struct {
 	// PathOverrides defines paths that should be overridden with specific
 	// environment variable grouping.
 	PathOverrides []PathOverride `yaml:"path_overrides,omitempty" ignored:"true"`
+	// MaxSearchDepth configures the number of folders that Infracost should
+	// traverse to detect projects.
+	MaxSearchDepth int `yaml:"max_search_depth,omitempty" ignored:"true"`
 }
 
 type PathOverride struct {
@@ -118,6 +121,7 @@ type Config struct {
 	EnableCloud               *bool `yaml:"enable_cloud,omitempty" envconfig:"ENABLE_CLOUD"`
 	EnableCloudUpload         *bool `yaml:"enable_cloud_upload,omitempty" envconfig:"ENABLE_CLOUD_UPLOAD"`
 	DisableHCLParsing         bool  `yaml:"disable_hcl_parsing,omitempty" envconfig:"DISABLE_HCL_PARSING"`
+	GraphEvaluator            bool  `yaml:"graph_evaluator,omitempty" envconfig:"GRAPH_EVALUATOR"`
 
 	TLSInsecureSkipVerify *bool  `envconfig:"TLS_INSECURE_SKIP_VERIFY"`
 	TLSCACertFile         string `envconfig:"TLS_CA_CERT_FILE"`
