@@ -19,10 +19,23 @@ var (
 	defaultInfracostTmplName = "infracost.yml.tmpl"
 )
 
+type DetectedProject struct {
+	Name              string
+	Path              string
+	TerraformVarFiles []string
+}
+
+type DetectedRooModule struct {
+	Path     string
+	Projects []DetectedProject
+}
+
 // Variables hold the global variables that are passed into any template that the Parser evaluates.
 type Variables struct {
-	Branch     string
-	BaseBranch string
+	Branch              string
+	BaseBranch          string
+	DetectedProjects    []DetectedProject
+	DetectedRootModules []DetectedRooModule
 }
 
 // Parser is the representation of an initialized Infracost template parser.
