@@ -24,6 +24,7 @@ import (
 	"github.com/infracost/infracost/internal/hcl/funcs"
 	"github.com/infracost/infracost/internal/hcl/modules"
 	"github.com/infracost/infracost/internal/logging"
+	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/ui"
 )
 
@@ -94,6 +95,7 @@ type Evaluator struct {
 	blockBuilder   BlockBuilder
 	newSpinner     ui.SpinnerFunc
 	logger         zerolog.Logger
+	isGraph        bool
 	filteredBlocks []*Block
 }
 
@@ -110,13 +112,32 @@ func NewEvaluator(
 	blockBuilder BlockBuilder,
 	spinFunc ui.SpinnerFunc,
 	logger zerolog.Logger,
+	isGraph bool,
 ) *Evaluator {
 	ctx := NewContext(&hcl.EvalContext{
 		Functions: ExpFunctions(module.RootPath, logger),
 	}, nil, logger)
 
-	for key, provider := range module.Providers {
-		ctx.Set(provider, key)
+	// Add any provider references from blocks in this module.
+	// We do this here instead of loadModuleWithProviders to make sure
+	// this also works with the root module
+	if module.ProviderReferences == nil {
+		module.ProviderReferences = make(map[string]*Block)
+	}
+
+	providerBlocks := module.Blocks.OfType("provider")
+	for _, block := range providerBlocks {
+		k := block.Label()
+
+		alias := block.GetAttribute("alias")
+		if alias != nil {
+			k = k + "." + alias.AsString()
+		}
+		module.ProviderReferences[k] = block
+	}
+
+	for key, provider := range module.ProviderReferences {
+		ctx.Set(provider.Values(), key)
 	}
 
 	if visitedModules == nil {
@@ -164,13 +185,10 @@ func NewEvaluator(
 		blockBuilder:   blockBuilder,
 		newSpinner:     spinFunc,
 		logger:         l,
+		isGraph:        isGraph,
 	}
 }
 
-func (e *Evaluator) isGraphEvaluator() bool {
-	return os.Getenv("INFRACOST_GRAPH_EVALUATOR") == "true"
-}
-
 func (e *Evaluator) AddFilteredBlocks(blocks ...*Block) {
 	for _, block := range blocks {
 		if block != nil {
@@ -249,10 +267,16 @@ func (e *Evaluator) collectModules() *Module {
 		root.Modules = append(root.Modules, definition.Module)
 	}
 
+	// Reload the provider references for this module instance
+	// We need to do this so when we call ProviderConfigKey() we get the fully
+	// resolved provider. We might be able to improve this by only evaluating the
+	// provider block when we need it.
+	for name, providerBlock := range root.ProviderReferences {
+		e.ctx.Set(providerBlock.Values(), name)
+	}
+
 	if v := e.MissingVars(); len(v) > 0 {
-		root.Warnings = []Warning{
-			NewMissingVarsWarning(v),
-		}
+		root.Warnings = append(root.Warnings, schema.NewDiagMissingVars(v...))
 	}
 
 	return &root
@@ -331,16 +355,16 @@ func (e *Evaluator) evaluateModules() {
 
 		moduleEvaluator := NewEvaluator(
 			Module{
-				Name:       fullName,
-				Source:     moduleCall.Module.Source,
-				Providers:  moduleCall.Module.Providers,
-				Blocks:     moduleCall.Module.RawBlocks,
-				RawBlocks:  moduleCall.Module.RawBlocks,
-				RootPath:   e.module.RootPath,
-				ModulePath: moduleCall.Path,
-				Modules:    nil,
-				Parent:     &e.module,
-				SourceURL:  moduleCall.Module.SourceURL,
+				Name:               fullName,
+				Source:             moduleCall.Module.Source,
+				Blocks:             moduleCall.Module.RawBlocks,
+				RawBlocks:          moduleCall.Module.RawBlocks,
+				RootPath:           e.module.RootPath,
+				ModulePath:         moduleCall.Path,
+				Modules:            nil,
+				Parent:             &e.module,
+				SourceURL:          moduleCall.Module.SourceURL,
+				ProviderReferences: moduleCall.Module.ProviderReferences,
 			},
 			e.workingDir,
 			vars,
@@ -350,6 +374,7 @@ func (e *Evaluator) evaluateModules() {
 			e.blockBuilder,
 			nil,
 			e.logger,
+			e.isGraph,
 		)
 
 		moduleCall.Module, _ = moduleEvaluator.Run()
@@ -428,7 +453,7 @@ func (e *Evaluator) expandDynamicBlock(b *Block) *Block {
 		// for each expanded dynamic block add the generated "content" as a
 		// new child block into the parent block.
 		expanded := e.expandBlockForEaches([]*Block{child})
-		for _, ex := range expanded {
+		for i, ex := range expanded {
 			content := ex.GetChildBlock("content")
 			if content == nil {
 				continue
@@ -440,7 +465,7 @@ func (e *Evaluator) expandDynamicBlock(b *Block) *Block {
 			content.SetType(blockName)
 
 			for attrName, attr := range content.AttributesAsMap() {
-				b.context.Root().SetByDot(attr.Value(), fmt.Sprintf("%s.%s.%s", b.Reference().String(), blockName, attrName))
+				b.context.Root().SetByDot(attr.Value(), fmt.Sprintf("%s.%s.%d.%s", b.Reference().String(), blockName, i, attrName))
 			}
 
 			newChildBlocks = append(newChildBlocks, content)
@@ -464,6 +489,7 @@ func (e *Evaluator) expandDynamicBlock(b *Block) *Block {
 		parent:      b.parent,
 		verbose:     b.verbose,
 		logger:      b.logger,
+		isGraph:     b.isGraph,
 		newMock:     b.newMock,
 		attributes:  b.attributes,
 		reference:   b.reference,
@@ -523,7 +549,7 @@ func (e *Evaluator) expandBlockForEaches(blocks Blocks) Blocks {
 			continue
 		}
 
-		if !e.isGraphEvaluator() && (block.IsCountExpanded() || !block.IsForEachReferencedExpanded(blocks) || !shouldExpandBlock(block)) {
+		if !e.isGraph && (block.IsCountExpanded() || !block.IsForEachReferencedExpanded(blocks) || !shouldExpandBlock(block)) {
 			original := block.original.GetAttribute("for_each")
 			if !original.HasChanged() {
 				expanded = append(expanded, block)
@@ -586,7 +612,7 @@ func (e *Evaluator) expandBlockForEaches(blocks Blocks) Blocks {
 					if v, ok := e.moduleCalls[clone.FullName()]; ok {
 						v.Definition = clone
 					} else {
-						modCall, err := e.loadModule(clone)
+						modCall, err := e.loadModuleWithProviders(clone)
 						if err != nil {
 							e.logger.Debug().Err(err).Msgf("failed to create expanded module call, could not load module %s", clone.FullName())
 							return false
@@ -695,7 +721,7 @@ func (e *Evaluator) expandBlockCounts(blocks Blocks) Blocks {
 			continue
 		}
 
-		if !e.isGraphEvaluator() && (block.IsCountExpanded() || !shouldExpandBlock(block)) {
+		if !e.isGraph && (block.IsCountExpanded() || !shouldExpandBlock(block)) {
 			original := block.original.GetAttribute("count")
 			if !original.HasChanged() {
 				expanded = append(expanded, block)
@@ -710,7 +736,7 @@ func (e *Evaluator) expandBlockCounts(blocks Blocks) Blocks {
 		value := countAttr.Value()
 		if !value.IsNull() && value.IsKnown() {
 			v := countAttr.AsInt()
-			if v <= math.MaxInt32 {
+			if v >= 0 && v <= math.MaxInt32 {
 				count = int(v)
 			}
 		}
@@ -986,6 +1012,37 @@ func (e *Evaluator) expandedEachBlockToValue(b *Block, existingValues map[string
 	return cty.ObjectVal(ob)
 }
 
+// loadModuleWithProviders takes in a module "x" {} block and loads resources etc. into e.moduleBlocks.
+// Additionally, it returns variables to add to ["module.x.*"] variables
+func (e *Evaluator) loadModuleWithProviders(b *Block) (*ModuleCall, error) {
+	modCall, err := e.loadModule(b)
+	if err != nil {
+		return modCall, err
+	}
+
+	// Pass any provider references that should be inherited by the module.
+	// This includes any implicit providers that are inherited from the parent
+	// module, as well as any explicit provider references that are passed in
+	// via the "providers" attribute.
+	providerRefs := map[string]*Block{}
+
+	for key, block := range e.module.ProviderReferences {
+		providerRefs[key] = block
+	}
+
+	providerAttr := b.GetAttribute("providers")
+	if providerAttr != nil {
+		decodedProviders := providerAttr.DecodeProviders()
+		for key, val := range decodedProviders {
+			providerRefs[key] = providerRefs[val]
+		}
+	}
+
+	modCall.Module.ProviderReferences = providerRefs
+
+	return modCall, nil
+}
+
 // loadModule takes in a module "x" {} block and loads resources etc. into e.moduleBlocks.
 // Additionally, it returns variables to add to ["module.x.*"] variables
 func (e *Evaluator) loadModule(b *Block) (*ModuleCall, error) {
@@ -993,26 +1050,9 @@ func (e *Evaluator) loadModule(b *Block) (*ModuleCall, error) {
 		return nil, fmt.Errorf("module without label: %s", b.FullName())
 	}
 
-	providers := map[string]cty.Value{}
-	providerBlocks := e.getValuesByBlockType("provider")
-	for key, provider := range providerBlocks.AsValueMap() {
-		providers[key] = provider
-	}
-	// inherit any providers from the providers block from the parent module
-	for key, provider := range e.module.Providers {
-		providers[key] = provider
-	}
-
 	var source string
-
 	attrs := b.AttributesAsMap()
 	for _, attr := range attrs {
-		if attr.Name() == "providers" {
-			val := attr.Value()
-			if val.Type().IsObjectType() && val.IsKnown() {
-				providers = attr.Value().AsValueMap()
-			}
-		}
 		if attr.Name() == "source" {
 			source = attr.AsString()
 		}
@@ -1062,7 +1102,6 @@ func (e *Evaluator) loadModule(b *Block) (*ModuleCall, error) {
 		Module: &Module{
 			Name:       b.TypeLabel(),
 			Source:     source,
-			Providers:  providers,
 			SourceURL:  moduleURL,
 			Blocks:     blocks,
 			RawBlocks:  blocks,
@@ -1098,7 +1137,7 @@ func (e *Evaluator) loadModules(lastContext hcl.EvalContext) {
 			continue
 		}
 
-		moduleCall, err := e.loadModule(moduleBlock)
+		moduleCall, err := e.loadModuleWithProviders(moduleBlock)
 		if err != nil {
 			e.logger.Debug().Err(err).Msgf("failed to load module %s ignoring", moduleBlock.LocalName())
 			continue
