@@ -762,8 +762,11 @@ func formatCounts(countMap *map[string]int) string {
 	return msg
 }
 
-func hasSupportedTerraformProvider(rType string) bool {
-	return strings.HasPrefix(rType, "aws_") || strings.HasPrefix(rType, "google_") || strings.HasPrefix(rType, "azurerm_")
+func hasSupportedProvider(rType string) bool {
+	return strings.HasPrefix(rType, "aws_") || // tf
+		strings.HasPrefix(rType, "google_") || // tf
+		strings.HasPrefix(rType, "azurerm_") || // tf
+		strings.HasPrefix(rType, "AWS::") // cf
 }
 
 func BuildSummary(resources []*schema.Resource, opts SummaryOptions) (*Summary, error) {
@@ -789,7 +792,7 @@ func BuildSummary(resources []*schema.Resource, opts SummaryOptions) (*Summary,
 	}
 
 	for _, r := range resources {
-		if !opts.IncludeUnsupportedProviders && !hasSupportedTerraformProvider(r.ResourceType) {
+		if !opts.IncludeUnsupportedProviders && !hasSupportedProvider(r.ResourceType) {
 			continue
 		}
 
