@@ -4,7 +4,7 @@ import (
 	"regexp"
 	"strings"
 
-	log "github.com/sirupsen/logrus"
+	"github.com/rs/zerolog/log"
 
 	"github.com/infracost/infracost/internal/resources/aws"
 	"github.com/infracost/infracost/internal/schema"
@@ -23,7 +23,7 @@ func newDirectoryServiceDirectory(d *schema.ResourceData, u *schema.UsageData) *
 	region := d.Get("region").String()
 	regionName, ok := aws.RegionMapping[region]
 	if !ok {
-		log.Warnf("Could not find mapping for resource %s region %s", d.Address, region)
+		log.Warn().Msgf("Could not find mapping for resource %s region %s", d.Address, region)
 	}
 
 	a := &aws.DirectoryServiceDirectory{
