@@ -1,8 +1,9 @@
 package azure
 
 import (
+	"github.com/rs/zerolog/log"
+
 	"github.com/infracost/infracost/internal/schema"
-	log "github.com/sirupsen/logrus"
 )
 
 func GetAzureRMCosmosdbCassandraTableRegistryItem() *schema.RegistryItem {
@@ -26,9 +27,9 @@ func NewAzureRMCosmosdbCassandraTable(d *schema.ResourceData, u *schema.UsageDat
 				CostComponents: cosmosDBCostComponents(d, u, account),
 			}
 		}
-		log.Warnf("Skipping resource %s as its 'cassandra_keyspace_id.account_name' property could not be found.", d.Address)
+		log.Warn().Msgf("Skipping resource %s as its 'cassandra_keyspace_id.account_name' property could not be found.", d.Address)
 		return nil
 	}
-	log.Warnf("Skipping resource %s as its 'cassandra_keyspace_id' property could not be found.", d.Address)
+	log.Warn().Msgf("Skipping resource %s as its 'cassandra_keyspace_id' property could not be found.", d.Address)
 	return nil
 }
