@@ -7,9 +7,9 @@ import (
 	"github.com/infracost/infracost/internal/schema"
 )
 
-// getAzureRMFrontdoorFirewallPolicyRegistryItem returns a registry item for the
+// getFrontdoorFirewallPolicyRegistryItem returns a registry item for the
 // resource
-func getAzureRMFrontdoorFirewallPolicyRegistryItem() *schema.RegistryItem {
+func getFrontdoorFirewallPolicyRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:  "azurerm_frontdoor_firewall_policy",
 		RFunc: newFrontdoorFirewallPolicy,
