@@ -5,7 +5,7 @@ import (
 	"github.com/infracost/infracost/internal/schema"
 )
 
-func getAzureRMPointToSiteVpnGatewayRegistryItem() *schema.RegistryItem {
+func getPointToSiteVpnGatewayRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:  "azurerm_point_to_site_vpn_gateway",
 		RFunc: newPointToSiteVpnGateway,
