@@ -7,7 +7,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getActiveDirectoryDomainServiceRegistryItem(),
 	getActiveDirectoryDomainServiceReplicaSetRegistryItem(),
 	getAPIManagementRegistryItem(),
-	GetAzureRMApplicationGatewayRegistryItem(),
+	getApplicationGatewayRegistryItem(),
 	getAppServiceEnvironmentRegistryItem(),
 	GetAzureRMAppIntegrationServiceEnvironmentRegistryItem(),
 	getFunctionAppRegistryItem(),
@@ -22,9 +22,10 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getAutomationDSCConfigurationRegistryItem(),
 	getAutomationDSCNodeConfigurationRegistryItem(),
 	getAutomationJobScheduleRegistryItem(),
-	GetAzureRMBastionHostRegistryItem(),
+	getBastionHostRegistryItem(),
 	GetAzureRMCDNEndpointRegistryItem(),
 	getContainerRegistryRegistryItem(),
+	getCosmosDBAccountRegistryItem(),
 	GetAzureRMCosmosdbCassandraKeyspaceRegistryItem(),
 	GetAzureRMCosmosdbCassandraTableRegistryItem(),
 	GetAzureRMCosmosdbGremlinDatabaseRegistryItem(),
@@ -44,14 +45,14 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getDNSPtrRecordRegistryItem(),
 	getDNSSrvRecordRegistryItem(),
 	getDNSTxtRecordRegistryItem(),
-	GetAzureRMDNSPrivateZoneRegistryItem(),
-	GetAzureRMDNSZoneRegistryItem(),
+	getDNSPrivateZoneRegistryItem(),
+	getDNSZoneRegistryItem(),
 	GetAzureRMEventHubsNamespaceRegistryItem(),
-	getAzureRMExpressRouteConnectionRegistryItem(),
-	getAzureRMExpressRouteGatewayRegistryItem(),
+	getExpressRouteConnectionRegistryItem(),
+	getExpressRouteGatewayRegistryItem(),
 	GetAzureRMFirewallRegistryItem(),
-	getAzureRMFrontdoorFirewallPolicyRegistryItem(),
-	getAzureRMFrontdoorRegistryItem(),
+	getFrontdoorFirewallPolicyRegistryItem(),
+	getFrontdoorRegistryItem(),
 	GetAzureRMHDInsightHadoopClusterRegistryItem(),
 	GetAzureRMHDInsightHBaseClusterRegistryItem(),
 	GetAzureRMHDInsightInteractiveQueryClusterRegistryItem(),
@@ -60,22 +61,22 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMKeyVaultCertificateRegistryItem(),
 	GetAzureRMKeyVaultKeyRegistryItem(),
 	GetAzureRMKeyVaultManagedHSMRegistryItem(),
-	GetAzureRMKubernetesClusterRegistryItem(),
-	GetAzureRMKubernetesClusterNodePoolRegistryItem(),
-	GetAzureRMLoadBalancerRegistryItem(),
+	getKubernetesClusterRegistryItem(),
+	getKubernetesClusterNodePoolRegistryItem(),
+	getLoadBalancerRegistryItem(),
 	GetAzureRMLoadBalancerRuleRegistryItem(),
 	GetAzureRMLoadBalancerOutboundRuleRegistryItem(),
 	getLinuxFunctionAppRegistryItem(),
-	GetAzureRMLinuxVirtualMachineRegistryItem(),
-	GetAzureRMLinuxVirtualMachineScaleSetRegistryItem(),
-	getAzureRMLogAnalyticsWorkspaceRegistryItem(),
-	GetAzureRMManagedDiskRegistryItem(),
+	getLinuxVirtualMachineRegistryItem(),
+	getLinuxVirtualMachineScaleSetRegistryItem(),
+	getLogAnalyticsWorkspaceRegistryItem(),
+	getManagedDiskRegistryItem(),
 	GetAzureRMMariaDBServerRegistryItem(),
-	getAzureRMMSSQLDatabaseRegistryItem(),
+	getMSSQLDatabaseRegistryItem(),
 	GetAzureRMMySQLServerRegistryItem(),
 	GetAzureRMNotificationHubNamespaceRegistryItem(),
-	getAzureRMPointToSiteVpnGatewayRegistryItem(),
-	getAzureRMPostgreSQLFlexibleServerRegistryItem(),
+	getPointToSiteVpnGatewayRegistryItem(),
+	getPostgreSQLFlexibleServerRegistryItem(),
 	GetAzureRMPostgreSQLServerRegistryItem(),
 	getPrivateDNSARecordRegistryItem(),
 	getPrivateDNSAAAARecordRegistryItem(),
@@ -89,22 +90,22 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMPublicIPPrefixRegistryItem(),
 	GetAzureRMSearchServiceRegistryItem(),
 	GetAzureRMRedisCacheRegistryItem(),
-	getAzureRMStorageAccountRegistryItem(),
-	getAzureRMSQLDatabaseRegistryItem(),
-	getAzureRMSQLManagedInstanceRegistryItem(),
 	getAzureRMMSSQLManagedInstanceRegistryItem(),
+	getStorageAccountRegistryItem(),
+	getSQLDatabaseRegistryItem(),
+	getSQLManagedInstanceRegistryItem(),
 	GetAzureRMSynapseSparkPoolRegistryItem(),
 	GetAzureRMSynapseSQLPoolRegistryItem(),
 	GetAzureRMSynapseWorkspacRegistryItem(),
-	getAzureRMVirtualHubRegistryItem(),
-	GetAzureRMVirtualMachineScaleSetRegistryItem(),
-	GetAzureRMVirtualMachineRegistryItem(),
+	getVirtualHubRegistryItem(),
+	getVirtualMachineScaleSetRegistryItem(),
+	getVirtualMachineRegistryItem(),
 	GetAzureRMVirtualNetworkGatewayConnectionRegistryItem(),
 	GetAzureRMVirtualNetworkGatewayRegistryItem(),
-	GetAzureRMWindowsVirtualMachineRegistryItem(),
-	GetAzureRMWindowsVirtualMachineScaleSetRegistryItem(),
-	getAzureRMVPNGatewayRegistryItem(),
-	getAzureRMVPNGatewayConnectionRegistryItem(),
+	getWindowsVirtualMachineRegistryItem(),
+	getWindowsVirtualMachineScaleSetRegistryItem(),
+	getVPNGatewayRegistryItem(),
+	getVPNGatewayConnectionRegistryItem(),
 	getDataFactoryRegistryItem(),
 	getDataFactoryIntegrationRuntimeAzureRegistryItem(),
 	getDataFactoryIntegrationRuntimeAzureSSISRegistryItem(),
@@ -159,6 +160,8 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getPrivateDnsResolverInboundEndpointRegistryItem(),
 	getPrivateDnsResolverOutboundEndpointRegistryItem(),
 	getPrivateDnsResolverDnsForwardingRulesetRegistryItem(),
+	getMachineLearningComputeInstanceRegistryItem(),
+	getMachineLearningComputeClusterRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
@@ -254,13 +257,25 @@ var FreeResources = []string{
 	// Azure CDN
 	"azurerm_cdn_profile",
 
+	// Azure Consumption
+	"azurerm_consumption_budget_management_group",
+	"azurerm_consumption_budget_resource_group",
+	"azurerm_consumption_budget_subscription",
+
 	// Azure CosmosDB
-	"azurerm_cosmosdb_account",
 	"azurerm_cosmosdb_notebook_workspace",
 	"azurerm_cosmosdb_sql_stored_procedure",
 	"azurerm_cosmosdb_sql_trigger",
 	"azurerm_cosmosdb_sql_user_defined_function",
 
+	// Azure Cost Management
+	"azurerm_cost_anomaly_alert",
+	"azurerm_cost_management_scheduled_action",
+	"azurerm_resource_group_cost_management_export",
+	"azurerm_resource_group_cost_management_view",
+	"azurerm_subscription_cost_management_export",
+	"azurerm_subscription_cost_management_view",
+
 	// Azure DNS
 	"azurerm_private_dns_zone_virtual_network_link",
 	"azurerm_private_dns_resolver",
@@ -407,6 +422,9 @@ var FreeResources = []string{
 	"azurerm_logic_app_trigger_recurrence",
 	"azurerm_logic_app_workflow",
 
+	// Azure Machine Learning
+	"azurerm_machine_learning_workspace",
+
 	// Azure Management
 	"azurerm_management_group",
 	"azurerm_management_group_subscription_association",
@@ -489,6 +507,9 @@ var FreeResources = []string{
 	"azurerm_policy_definition",
 	"azurerm_policy_remediation",
 	"azurerm_policy_set_definition",
+	"azurerm_subscription_policy_assignment",
+	"azurerm_subscription_policy_exemption",
+	"azurerm_subscription_policy_remediation",
 
 	// Azure Portal
 	"azurerm_dashboard",
@@ -586,6 +607,10 @@ var FreeResources = []string{
 	"azurerm_synapse_firewall_rule",
 	"azurerm_synapse_private_link_hub",
 
+	// Azure Virtual Hub
+	"azurerm_virtual_hub_route_table",
+	"azurerm_virtual_hub_route_table_route",
+
 	// Azure Virtual Machines
 	"azurerm_virtual_machine_data_disk_attachment",
 	"azurerm_virtual_machine_extension",
