@@ -5,7 +5,7 @@ import (
 	"github.com/infracost/infracost/internal/schema"
 )
 
-func getAzureRMSQLManagedInstanceRegistryItem() *schema.RegistryItem {
+func getSQLManagedInstanceRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:  "azurerm_sql_managed_instance",
 		RFunc: newSQLManagedInstance,
